@@ -5,7 +5,7 @@ package Bundle::SYP;
 use strict;
 use utf8;
 use warnings 'all';
-our $VERSION = '0.5'; # VERSION
+our $VERSION = '0.6'; # VERSION
 
 1;
 
@@ -21,12 +21,12 @@ Bundle::SYP - SYP's cozy environment
 
 =head1 VERSION
 
-version 0.5
+version 0.6
 
 =head1 SYNOPSIS
 
- # Ubuntu Server 10.04.2 LTS
- apt-get install curl gcc git-core libcurl4-gnutls-dev libexpat-dev libncurses-dev libreadline-dev
+ # Debian >= 5.0; Perl >= 5.14
+ sudo apt-get install curl gcc git-core libcurl4-gnutls-dev libdb-dev libexpat-dev libncurses-dev libreadline-dev libxml2-dev
 
  perl -MCPAN -e 'install Bundle::SYP'
 
@@ -122,6 +122,10 @@ Mojolicious
 
 Moose
 
+MooseX::NonMoose
+
+Net::Curl
+
 Number::Format
 
 Perl::Critic
@@ -132,6 +136,8 @@ Perl::Tidy
 
 Pod::Elemental
 
+Pod::Elemental::Transformer::List
+
 Pod::Simple
 
 Pod::Weaver::Plugin::Encoding
